Survey
-------

Sisters Rise Up
===============

Sisters Rise Up is a research study at the University of Michigan that is trying to determine ways to help women of color (Black, Latinx, and/or Native American) who are taking Advanced Placement Computer Science A (CSA) succeed in the course and on the exam.  It offers free remote one-hour help sessions twice a week which are led by undergraduate students at the University of Michigan.  If you are interested in Sisters Rise Up please fill out the form at https://tinyurl.com/55z7tyb9 with your parent or guardian's contact information.

Sisters Rise Up will cover concepts on the AP CS exams, answer your questions, and introduce you to role models.  Students who have been in Sisters Rise Up value meeting other women like them in computing, getting their questions answered, going deeper into topics, and learning about opportunities in computing.

If you have questions please email Barbara Ericson (barbarer@umich.edu).


Survey
======

.. |Privacy Policy| raw:: html

   <a href="https://runestone.academy/runestone/default/privacy" target="_blank" style="text-decoration:underline">Runestone Academy Privacy Policy</a>

Please log into Runestone and fill out the following survey.  You do not have to answer any of the following questions, but if you do, it will give us valuable information about who is using this ebook. Your answers to all questions on this site will be used for educational research and to improve the ebook.  Any identifying information, such as your name, will be removed from the data before it is analyzed and used in publications (|Privacy Policy|).

.. qnum::
   :prefix: 1-1-7-
   :start: 1

.. poll:: qstudent
   :option_1: student
   :option_2: teacher
   :option_3: other
   :option_4: prefer not to answer

   I am a :




.. poll:: qgender
   :option_1: female
   :option_2: male
   :option_3: non-binary
   :option_4: other
   :option_5: prefer not to answer

   I am :



.. poll:: qrace
   :option_1: African-American/Black
   :option_2: American Indian/Alaska Native
   :option_3: Asian
   :option_4: Hispanic/Latina/o
   :option_5: Native Hawaiian/Pacific Islander
   :option_6: White
   :option_7: Multiple races/ethnicities
   :option_8: Other
   :option_9: Prefer not to answer

   I am :


.. poll:: qdisability
   :option_1: yes
   :option_2: no
   :option_3: prefer not to answer

   I have a documented disability or student accommodations.


.. poll:: qprogramming
   :option_1: beginner programmer
   :option_2: intermediate programmer
   :option_3: expert programmer
   :option_4: prefer not to answer

   I am a :


.. poll:: qblockprogramming
   :option_1: no programming
   :option_2: block-based programming (like App Inventor)
   :option_3: text-based programming (like Java)
   :option_4: both block and text-based programming

   I have experience with:

.. poll:: qcsp
   :option_1: Yes, I took AP CSP.
   :option_2: No, I did not take AP CSP.

   I took AP CSP (Computer Science Principles) before this CSA course.

.. shortanswer:: qprogrammingtype

    If you have taken a programming course before, please tell us what programming language you learned and how long the course was.


.. poll:: qjavaconfidence
   :option_1: strongly agree
   :option_2: agree
   :option_3: neither agree or disagree
   :option_4: disagree
   :option_5: strongly disagree
   :option_6: prefer not to answer

   I am confident that I can learn Java.

.. poll:: qconfidence
   :option_1: strongly agree
   :option_2: agree
   :option_3: neither agree or disagree
   :option_4: disagree
   :option_5: strongly disagree
   :option_6: prefer not to answer

   I am confident that I will do well in this course and the AP CSA exam.

.. poll:: qcareer
   :option_1: strongly agree
   :option_2: agree
   :option_3: neither agree or disagree
   :option_4: disagree
   :option_5: strongly disagree
   :option_6: prefer not to answer

   I would like to pursue further study or a career in computing.



